@@ -489,7 +489,10 @@ typedef enum CUpti_driver_api_trace_cbid_enum {
     CUPTI_DRIVER_TRACE_CBID_cuEventCreateFromEGLSync                                       = 479,
     CUPTI_DRIVER_TRACE_CBID_cuLaunchCooperativeKernelMultiDevice                           = 480,
     CUPTI_DRIVER_TRACE_CBID_cuFuncSetAttribute                                             = 481,
-    CUPTI_DRIVER_TRACE_CBID_SIZE                                                           = 482,
+    CUPTI_DRIVER_TRACE_CBID_cuDeviceGetUuid                                                = 482,
+    CUPTI_DRIVER_TRACE_CBID_cuStreamGetCtx                                                 = 483,
+    CUPTI_DRIVER_TRACE_CBID_cuStreamGetCtx_ptsz                                            = 484,
+    CUPTI_DRIVER_TRACE_CBID_SIZE                                                           = 485,
     CUPTI_DRIVER_TRACE_CBID_FORCE_INT                                                      = 0x7fffffff
 } CUpti_driver_api_trace_cbid;
 
