@@ -111,8 +111,12 @@ typedef enum {
   CUPTI_METRIC_CATEGORY_TEXTURE         = 4,
   /**
    *A Nvlink related metric.
-  */
+   */
   CUPTI_METRIC_CATEGORY_NVLINK          = 5,
+  /**
+   *A PCIe related metric.
+   */
+  CUPTI_METRIC_CATEGORY_PCIE           = 6,
   CUPTI_METRIC_CATEGORY_FORCE_INT                         = 0x7fffffff,
 } CUpti_MetricCategory;
 
