@@ -35,7 +35,9 @@ static void initVec(const int n, const float mult, float *x)
     int i;
     // CUPTI OpenACC only supports NVIDIA devices
 #pragma acc kernels
+#if (!defined(HOST_ARCH_PPC))
     assert(acc_on_device(acc_device_nvidia));
+#endif
     for (i = 0; i < n; ++i)
         x[i] = mult*i;
 }
